@@ -109,7 +109,7 @@ class EqOdooConnection(OdooConnection):
                 continue
             if report.company_id:
                 IR_ACTIONS_REPORT.env.user.company_id = report.company_id[0]
-                if self.version == '13':
+                if self.version in ['13', '14']:
                     report_id = self._search_report_v13(report.model_name, report.entry_name, IR_ACTIONS_REPORT, report.company_id[0])
                 else:
                     report_id = self._search_report(report.model_name, report.entry_name, IR_ACTIONS_REPORT)
@@ -137,13 +137,22 @@ class EqOdooConnection(OdooConnection):
                         field_id = IR_MODEL_FIELDS.search(
                             [('model_id', '=', model_object.id), ('name', '=', field_name)])
                         if field_id:
-                            field = IR_MODEL_FIELDS.browse(field_id)
-                            # Insert the report_id
-                            if report_object.id not in field.eq_report_ids.ids:
-                                report_ids = field.eq_report_ids.ids + [report_object.id]
-                                field.write({'eq_report_ids': [(6, 0, report_ids)]})
-                                # field.update({'eq_report_ids': [(6, 0, report_ids)]})
-                                # field.update({'eq_report_ids': [(4, report_object.id)]})
+                            if report.company_id:
+                                # Only for Multi company
+                                report_list_ids = IR_MODEL_FIELDS.eq_get_field_report_ids(field_id)
+                                field = IR_MODEL_FIELDS.browse(field_id)
+                                # Insert the report_id
+                                if report_object.id not in report_list_ids:
+                                    report_ids = report_list_ids + [report_object.id]
+                                    field.write({'eq_report_ids': [(6, 0, report_ids)]})
+                            else:
+                                field = IR_MODEL_FIELDS.browse(field_id)
+                                # Insert the report_id
+                                if report_object.id not in field.eq_report_ids.ids:
+                                    report_ids = field.eq_report_ids.ids + [report_object.id]
+                                    field.write({'eq_report_ids': [(6, 0, report_ids)]})
+                                    # field.update({'eq_report_ids': [(6, 0, report_ids)]})
+                                    # field.update({'eq_report_ids': [(4, report_object.id)]})
                 if report._calculated_fields:
                     for field, content in report._calculated_fields.items():
                         for function_name, parameter in content.items():
@@ -161,7 +170,7 @@ class EqOdooConnection(OdooConnection):
         for company_id in company_ids:
             # Change the current company in the env
             self.connection.env.user.company_id = company_id
-            
+
             if self.version == "10":
                 IR_ACTIONS_REPORT = self.connection.env['ir.actions.report.xml']
             else:
@@ -175,7 +184,7 @@ class EqOdooConnection(OdooConnection):
             # Get current company name
             company_name = self.connection.env['res.company'].browse(company_id).name
             print('Collect fields for %s' %company_name)
-            
+
             # Progressbar...
             with click.progressbar(all_report_field_ids, length=len(all_report_field_ids)) as bar:
                 for field_id in bar:
@@ -229,13 +238,13 @@ class EqOdooConnection(OdooConnection):
         IR_FIELDS = self.connection.env['ir.model.fields']
         IR_MODEL = self.connection.env['ir.model']
         model_id = IR_MODEL.search([('model','=', model_name)])
-        field_id = IR_FIELDS.search([('model_id','=', model_id), ('name','=', field_name)])
+        field_id = IR_FIELDS.search([('model_id','=', model_id[0]), ('name','=', field_name)])
         field_obj = IR_FIELDS.browse(field_id)
         modules_dependencies = field_obj.modules.replace(' ', '').split(',')
         if 'dependencies' in data_dictionary[report_id]:
             data_dictionary[report_id]['dependencies'].extend(modules_dependencies)
             # using set()
-            # to remove duplicated 
+            # to remove duplicated
             # from list
             data_dictionary[report_id]['dependencies'] = list(set(data_dictionary[report_id]['dependencies']))
         else:
@@ -340,7 +349,7 @@ class EqOdooConnection(OdooConnection):
                 self.connection.env.user.company_id = report.company_id[0]
                 IR_ACTIONS_REPORT = self.connection.env['ir.actions.report']
                 IR_MODEL = self.connection.env['ir.model']
-                if self.version == '13':
+                if self.version in ['13', '14']:
                     report_id = self._search_report_v13(report.model_name, report.entry_name, IR_ACTIONS_REPORT, report.company_id[0])
                 else:
                     report_id = self._search_report(report.model_name, report.entry_name, IR_ACTIONS_REPORT)
@@ -351,7 +360,7 @@ class EqOdooConnection(OdooConnection):
             # Get report action record
             report_object = IR_ACTIONS_REPORT.browse(report_id) if report_id else False
             # Check if the report has been created and is type Fast Report
-            if not report_id or report_object.report_type != "fast_report": 
+            if not report_id or report_object.report_type != "fast_report":
                 logging.info(f"!!! ******** REPORT {report.report_name} NOT CREATED OR IS NOT TYPE FAST REPORT ******** !!!")
                 continue
 
@@ -359,7 +368,7 @@ class EqOdooConnection(OdooConnection):
 
             ## Get module from report model
             IR_REPORT_MODEL = self.connection.env[report.model_name]
-            
+
             ''' This is extra help: display modules from report model and report filename code
             # Get the report model object
             model_id = IR_MODEL.search([('model', '=', report.model_name)])
@@ -370,7 +379,7 @@ class EqOdooConnection(OdooConnection):
             Can be comented if not necessary '''
 
             if report_object:
-                # Get all report model records ids 
+                # Get all report model records ids
                 report_model_records_ids = IR_REPORT_MODEL.search([])
                 try:
                     if not len(report_model_records_ids):
